from setuptools import setup

setup(name='distributions_pav',
      version='0.1',
      description='Gaussian and binomial distributions',
      packages=['distributions_pav'],
      author= 'Pavan',
      zip_safe=False)
